@@ -1,6 +1,6 @@
 import requests
 
-def request(url):
+def request_json(url):
     
     try:
         
@@ -24,4 +24,4 @@ def get(url_base, url_key, type, id):
     
     elif type == "observation": url = url_base + "series/observations?series_id=" + id + url_key
         
-    return request(url)
\ No newline at end of file
+    return request_json(url)
\ No newline at end of file
